# -*- Mode: Python -*-
# vi:si:et:sw=4:sts=4:ts=4
#
# Flumotion - a streaming media server
# Copyright (C) 2004,2005,2006,2007 Fluendo, S.L. (www.fluendo.com).
# All rights reserved.

# This file may be distributed and/or modified under the terms of
# the GNU General Public License version 2 as published by
# the Free Software Foundation.
# This file is distributed without any warranty; without even the implied
# warranty of merchantability or fitness for a particular purpose.
# See "LICENSE.GPL" in the source distribution for more information.

# Licensees having purchased or holding a valid Flumotion Advanced
# Streaming Server license may use this file in accordance with the
# Flumotion Advanced Streaming Server Commercial License Agreement.
# See "LICENSE.Flumotion" in the source distribution for more information.

# Headers in this file shall remain intact.

__version__ = "$Rev: 7363 $"

import os

# in distcheck mode, the built .so module is in another path; make sure
# it can still be imported as usual
thisdir = os.path.dirname(__file__)
srcdir = os.path.abspath(os.path.join(thisdir, '..', '..', '..'))

if os.path.exists(os.path.join(srcdir, '_build')):
    __path__.append(os.path.join(srcdir, '_build',
        'flumotion', 'extern', 'fdpass'))
